class sigul::package {

    package { "sigul":
        ensure => installed,
    }
    host { 'sign-vault1':
            ip => '10.5.125.75',
        }
    host { 'sign-bridge1':
            ip => '10.5.125.71',
        }

    file { "/var/lib/sigul/.fedora-server-ca.cert":
        owner  => "sigul",
        group  => "sigul",
        mode   => 0644,
        source => "puppet:///config/secure/fedora-ca.cert",
        require => Package["sigul"],
    }

}

class sigul::bridge {
    include sigul::package
    package { "koji":
        ensure => installed,
    }

    file { "/etc/sigul/bridge.conf":
        owner   => "root",
        group   => "sigul",
        mode    => 0640,
        content => template("sigul/bridge.conf.erb"),
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/.fedora-upload-ca.cert":
        owner  => "sigul",
        group  => "sigul",
        mode   => 0644,
        source => "puppet:///config/secure/fedora-ca.cert",
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/cert8.db":
        owner   => "sigul",
        group   => "sigul",
        mode    => 0600,
        source  => "puppet:///config/secure/sigul_bridge_cert8.db",
        replace => false,
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/key3.db":
        owner   => "sigul",
        group   => "sigul",
        mode    => 0600,
        source  => "puppet:///config/secure/sigul_bridge_key3.db",
        replace => false,
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/secmod.db":
        owner   => "sigul",
        group   => "sigul",
        mode    => 0600,
        source  => "puppet:///config/secure/sigul_bridge_secmod.db",
        replace => false,
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/.fedora.cert":
        owner  => "sigul",
        group  => "sigul",
        mode   => 0644,
        source => "puppet:///config/secure/sigul_key_and_cert.pem",
        require => Package["sigul"],
    }

}

class sigul::server {
    include sigul::package

    file { "/etc/sigul/server.conf":
        owner   => "root",
        group   => "sigul",
        mode    => 0640,
        source  => "puppet:///sigul/server.conf",
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/cert8.db":
        owner   => "sigul",
        group   => "sigul",
        mode    => 0600,
        source  => "puppet:///config/secure/sigul_server_cert8.db",
        replace => false,
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/key3.db":
        owner   => "sigul",
        group   => "sigul",
        mode    => 0600,
        source  => "puppet:///config/secure/sigul_server_key3.db",
        replace => false,
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/secmod.db":
        owner   => "sigul",
        group   => "sigul",
        mode    => 0600,
        source  => "puppet:///config/secure/sigul_server_secmod.db",
        replace => false,
        require => Package["sigul"],
    }

    file { "/var/lib/sigul/gnupg/gpg.conf":
        owner   => "sigul",
        group   => "sigul",
        mode    => 0640,
        source  => "puppet:///sigul/gpg.conf",
        require => Package["sigul"],
    }


}

